#
# spec file for package perf
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perf
%define version %(rpm -q --qf '%{VERSION}' kernel-source)
Version:        %{version}
Release:        lp150.8.10.1
Summary:        Performance Monitoring Tools for Linux
License:        GPL-2.0-only
Group:          Development/Tools/Debuggers
Url:            https://perf.wiki.kernel.org/
BuildRequires:  asciidoc
BuildRequires:  audit-devel
BuildRequires:  binutils-devel
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gtk2-devel
BuildRequires:  kernel-source >= 2.6.31
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
# Use of Python2 authorized by behlert@suse.com for SLE15GA
# https://bugzilla.suse.com/show_bug.cgi?id=1082197#c18
BuildRequires:  python-devel
BuildRequires:  xz-devel
%ifarch aarch64 ia64 x86_64 ppc64 ppc64le ppc %sparc
BuildRequires:  libnuma-devel
%endif
%ifarch s390x s390
%define         _perf_unwind NO_LIBUNWIND=1
%else
%define         _perf_unwind %{nil}
BuildRequires:  libunwind-devel
%endif
BuildRequires:  newt-devel
BuildRequires:  openssl-devel
BuildRequires:  xmlto
BuildRequires:  zlib-devel
# dl_open requirement so not autodetected
%ifarch ppc64 ppc64le
Requires:       libebl
%endif
%{perl_requires}
%{?libperl_requires}
Patch1:         perf-report-remove-unnecessary-check-in-annotate_browser_write.patch
Patch2:         perf-annotate-browser-display-titles-in-left-frame.patch
Patch3:         perf-ftrace-move-setup_pager-before-opening-trace_pipe.patch
Patch4:         perf-evsel-set-attr-exclude_kernel-when-probing-max-attr-precise_ip.patch
Patch5:         perf-evsel-allow-asking-for-max-precise_ip-in-new_cycles.patch
Patch6:         perf-test-sdt-handle-realpath-failure.patch
Patch7:         perf-tests-attr-fix-no-delay-test.patch
Patch8:         perf-annotate-introduce-struct-sym_hist_entry.patch
Patch9:         perf-annotate-rename-sum-to-nr_samples-in-struct-sym_hist.patch
Patch10:        perf-hists-pass-perf_sample-to-_symbol__inc_addr_samples.patch
Patch11:        perf-annotate-store-the-sample-period-in-each-histogram-bucket.patch
Patch12:        perf-annotate-do-not-overwrite-sample-period.patch
Patch13:        perf-annotate-stdio-fix-show-total-period.patch
Patch14:        perf-jvmti-fix-linker-error-when-libelf-config-is-disabled.patch
Patch15:        perf-annotate-stdio-fix-column-header-when-using-show-total-period.patch
Patch16:        perf-annotate-stdio-set-enough-columns-for-show-total-period.patch
Patch17:        perf-annotate-fix-storing-per-line-sym_hist_entry.patch
Patch18:        perf-annotate-tui-use-sym_hist_entry-in-disasm_line_samples.patch
Patch19:        perf-annotate-tui-fix-show-total-period.patch
Patch20:        perf-annotate-tui-clarify-calculation-of-column-header-widths.patch
Patch21:        perf-annotate-tui-fix-column-header-when-toggling-period-percent.patch
Patch22:        perf-annotate-tui-set-appropriate-column-width-for-period-percent.patch
Patch23:        perf-scripting-python-add-ppc64le-to-audit-uname-list.patch
Patch24:        perf-test-make-list-subcommand-match-main-perf-test-numbering-matching.patch
Patch25:        perf-scripts-python-fix-missing-call_path_id-in-export-to-postgresql-script.patch
Patch26:        perf-trace-fix-off-by-one-string-allocation-problem.patch
Patch27:        perf-jevents-support-fcmask-and-portmask.patch
Patch28:        perf-annotate-stdio-support-show-nr-samples-option.patch
Patch29:        perf-annotate-document-show-total-period-option.patch
Patch30:        perf-vendor-events-add-core-event-list-for-skylake-server.patch
Patch31:        perf-vendor-events-add-skylake-server-uncore-event-list.patch
Patch32:        perf-tools-add-support-for-printing-new-mem_info-encodings.patch
Patch33:        perf-test-add-test-cases-for-new-data-source-encoding.patch
Patch34:        perf-tools-really-install-manpages-via-make-install-man.patch
Patch35:        perf-probe-fix-kprobe-blacklist-checking-condition.patch
Patch36:        perf-test-powerpc-fix-object-code-reading-test.patch
Patch37:        perf-pmu-extract-function-to-get-json-alias-map.patch
Patch38:        perf-evsel-fix-attr-exclude_kernel-setting-for-default-cycles-p.patch
Patch39:        perf-vendor-events-add-goldmont-plus-v1-event-file.patch
Patch40:        perf-symbols-fix-memory-corruption-because-of-zero-length-symbols.patch
Patch41:        perf-vendor-events-update-power9-events-e795dd42.patch
Patch42:        perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch
Patch43:        perf-mem-document-a-missing-option.patch
Patch44:        perf-vendor-events-update-power9-events-9749adc3.patch
Patch45:        perf-mem-allow-all-record-report-options.patch
Patch46:        perf-mem-document-incorrect-and-missing-options.patch
Patch47:        perf-script-show-hw-cache-events.patch
Patch48:        perf-mem-c2c-fix-perf_mem_events-to-support-powerpc.patch
# non upstream patches
Patch500:       perf-provide-definition-for-einval-on-32bit.patch

Requires:       kernel >= 2.6.31
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a userspace tool 'perf', which monitors performance for
either unmodified binaries or the entire system. It requires a Linux kernel
which includes the Performance Counters for Linux (PCL) subsystem (>= 2.6.31).
This subsystem utilizes the Performance Monitoring Unit (PMU) / hardware
counters of the underlying cpu architecture (if supported).

%prep
# copy necessary files from kernel-source since we need to modify them
(cd /usr/src/linux ; tar -cf - COPYING CREDITS README tools include scripts Kbuild Makefile arch/*/{include,lib,Makefile} lib) | tar -xf - 
chmod +x tools/perf/util/generate-cmdlist.sh
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p1
%patch36 -p1
%patch37 -p1
%patch38 -p1
%patch39 -p1
%patch40 -p1
%patch41 -p1
%patch42 -p1
%patch43 -p1
%patch44 -p1
%patch45 -p1
%patch46 -p1
%patch47 -p1
%patch48 -p1
%patch500 -p1

%build
cd tools/perf
export WERROR=0
# PASS rpm optflags as EXTRA_FLAGS,  passing as CFLAGS overrides and breaks build
make %{?_smp_mflags} -f Makefile.perf EXTRA_CFLAGS="%{optflags}" ASCIIDOC8=1 prefix=/usr libdir=%{_libdir} perfexecdir=lib/%{name}-core all doc %{_perf_unwind} tipdir=share/doc/packages/perf

%install
cd tools/perf
export WERROR=0
make -f Makefile.perf V=1 EXTRA_CFLAGS="%{optflags}" prefix=/usr libdir=%{_libdir} perfexecdir=lib/%{name}-core DESTDIR=%{buildroot} install install-doc %{_perf_unwind} tipdir=share/doc/packages/perf

%files
%defattr(-, root, root)
%attr(0644, root, root) %doc COPYING CREDITS README tools/perf/design.txt
%if 0%{?suse_version} > 1315
%attr(0644, root, root) %doc %{_docdir}/perf/tips.txt
%endif
%{_bindir}/perf
%{_bindir}/trace
%{_libdir}/libperf-gtk.so
%ifnarch armv7l
%dir %{_libdir}/traceevent
%dir %{_libdir}/traceevent/plugins
%{_libdir}/traceevent/plugins/plugin_*.so
%endif
%attr(0644, -, -) %{_sysconfdir}/bash_completion.d/perf
%{_libexecdir}/%{name}-core
%{_datarootdir}/%{name}-core
%{_mandir}/man1/perf*

%changelog
* Wed Jul 31 2019 Tony Jones <tonyj@suse.com>
- Add POWER mem/c2c support (FATE#326869, bsc#1124370)
  [Initial implementation was as FATE#326866 in SLE15-SP1]
  New patch: perf-mem-allow-all-record-report-options.patch
  New patch: perf-mem-c2c-fix-perf_mem_events-to-support-powerpc.patch
  New patch: perf-mem-document-a-missing-option.patch
  New patch: perf-mem-document-incorrect-and-missing-options.patch
* Mon Aug 27 2018 tonyj@suse.com
- libebl ppc64 dependancy was inadvertantly dropped, regression from
  "Thu Jun 15 22:27:56 - Add ppc64 requires on libebl (bsc#1040770)".
  Re-add dependancy (bsc#1106048)
* Wed Aug  1 2018 tonyj@suse.com
- Support crystall ridge / far / near memory indication in PEBS (FATE#325127)
  New patch: perf-test-add-test-cases-for-new-data-source-encoding.patch
  New patch: perf-tools-add-support-for-printing-new-mem_info-encodings.patch
* Wed Aug  1 2018 tonyj@suse.com
- PMU events are not listed because pvr code is missing for POWER9 (bsc#1075525 )
  New patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  New patch: perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch
* Fri Jul 27 2018 tonyj@suse.com
- Merge missing changes from SLE12-SP3 branch
  Thu Jan 18 01:12:14 UTC 2018 - tonyj@suse.com
  - Add necessary power pvr support (bsc#1075525)
    New patch: perf-pmu-events-support-additional-power8-pvr-in-mapfile.patch
    New patch: perf-vendor-events-add-power9-pmu-events.patch
    New patch: perf-vendor-events-add-power9-pvrs-to-mapfile.patch
    New patch: perf-vendor-events-powerpc-remove-suffix-in-mapfile.patch
    New patch: perf-vendor-events-update-power9-events-3c22ba52.patch
    New patch: perf-vendor-events-powerpc-remove-duplicate-events.patch
  Wed Dec  6 19:53:35 UTC 2017 - tonyj@suse.com
  - Add perf scripting support for ppc64le (bsc#1056756)
    New patch: perf-scripting-python-add-ppc64le-to-audit-uname
* Fri Jul 27 2018 tonyj@suse.com
- Resequence patches into Patch-mainline order
- Rename power event patches for consistency and to avoid exportpatch
  name clashes
  perf-vendor-events-update-power9-events.patch ->
    perf-vendor-events-update-power9-events-9749adc3.patch
  perf-vendor-events-powerpc-update-power9-events.patch ->
    perf-vendor-events-update-power9-events-e795dd42.patch
* Wed Jul 25 2018 tonyj@suse.com
- Initial checkin for SLE12-SP4.  Rebase off SLE15.
- Add JSON perf event lists for GLP (FATE#325092)
  new patch: perf-vendor-events-add-goldmont-plus-v1-event-file.patch
- Support perf core/uncore event list for Skylake server (FATE#325122)
  new patch: perf-vendor-events-add-core-event-list-for-skylake-server.patch
  new patch: perf-vendor-events-add-skylake-server-uncore-event-list.patch
  new patch: perf-jevents-support-fcmask-and-portmask.patch
* Tue Jun 12 2018 tonyj@suse.com
- perf script: Show hw-cache events (bsc#1096885)
  new patch: perf-script-show-hw-cache-events.patch
* Mon Apr  9 2018 tonyj@suse.com
- More Power9 event updates (bsc#1056686)
  New patch: perf-vendor-events-update-power9-events.patch
* Tue Apr  3 2018 tonyj@suse.com
- Add libpython support, regression from SLE12 (bsc#1082197)
* Fri Mar  9 2018 tonyj@suse.com
- Fix attr.exclude_kernel setting for default cycles:p (bsc#1083691)
  Regression from commit Mon Nov 27 23:45:48 UTC 2017
  New patch: perf-evsel-fix-attr-exclude_kernel-setting-for-default-cycles-p.patch
  New patch (dependent): perf-evsel-allow-asking-for-max-precise_ip-in-new_cycles.patch
- Git-fixes change (bsc#1070010)
  Fixes: perf-annotate-fix-storing-per-line-sym_hist_entry.patch (Mon Nov 27)
  New patch: perf-annotate-fix-storing-per-line-sym_hist_entry.patch
* Thu Feb 22 2018 tonyj@suse.com
- perf vendor events: Use more flexible pattern matching for CPU
  identification for mapfile.csv (bsc#1081960)
  New patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  New patch: perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch
* Thu Jan 18 2018 tonyj@suse.com
- powerpc: fix 'Object code reading' test (bsc#1073195)
  New patch: perf-test-powerpc-fix-object-code-reading-test.patch
* Mon Nov 27 2017 tonyj@suse.com
- Update power9 events (bsc#1069737)
  New patch: perf-vendor-events-powerpc-update-power9-events.patch
- Memory corruption due to zero length symbols (bsc#1068222)
  New patch: perf-symbols-fix-memory-corruption-because-of-zero-length-symbols.patc
- Incorporate fixes identified by git-fixes and their dependencies (bsc#1070010)
  New patch: perf-annotate-browser-display-titles-in-left-frame.patch
  New patch: perf-annotate-document-show-total-period-option.patch
  New patch: perf-annotate-do-not-overwrite-sample-period.patch
  New patch: perf-annotate-introduce-struct-sym_hist_entry.patch
  New patch: perf-annotate-rename-sum-to-nr_samples-in-struct-sym_hist.patch
  New patch: perf-annotate-stdio-fix-column-header-when-using-show-total-period.patch
  New patch: perf-annotate-stdio-fix-show-total-period.patch
  New patch: perf-annotate-stdio-set-enough-columns-for-show-total-period.patch
  New patch: perf-annotate-stdio-support-show-nr-samples-option.patch
  New patch: perf-annotate-store-the-sample-period-in-each-histogram-bucket.patch
  New patch: perf-annotate-tui-clarify-calculation-of-column-header-widths.patch  New patch: perf-annotate-tui-fix-column-header-when-toggling-period-percent.patch
  New patch: perf-annotate-tui-fix-show-total-period.patch
  New patch: perf-annotate-tui-set-appropriate-column-width-for-period-percent.patch
  New patch: perf-annotate-tui-use-sym_hist_entry-in-disasm_line_samples.patch
  New patch: perf-evsel-set-attr-exclude_kernel-when-probing-max-attr-precise_ip.patch
  New patch: perf-ftrace-move-setup_pager-before-opening-trace_pipe.patch
  New patch: perf-hists-pass-perf_sample-to-_symbol__inc_addr_samples.patch
  New patch: perf-jvmti-fix-linker-error-when-libelf-config-is-disabled.patch
  New patch: perf-probe-fix-kprobe-blacklist-checking-condition.patch
  New patch: perf-report-remove-unnecessary-check-in-annotate_browser_write.patch
  New patch: perf-scripts-python-fix-missing-call_path_id-in-export-to-postgresql-script.patch
  New patch: perf-test-make-list-subcommand-match-main-perf-test-numbering-matching.patch
  New patch: perf-tests-attr-fix-no-delay-test.patch
  New patch: perf-test-sdt-handle-realpath-failure.patch
  New patch: perf-tools-really-install-manpages-via-make-install-man.patch
  New patch: perf-trace-fix-off-by-one-string-allocation-problem.patch
* Fri Sep 15 2017 tonyj@suse.com
- Fix x86 32bit build error
  New patch: perf-provide-definition-for-einval-on-32bit.patch
* Thu Sep  1 2016 tonyj@suse.com
- Fix build error (tips.txt) on Leap42.2
- Fix doc file attributes
* Mon Jun  6 2016 jslaby@suse.com
- disable Werror completely. It breaks build due to shadow variables
  in external (perl) headers.
- add %%{?_smp_mflags}
* Mon Apr  4 2016 tonyj@suse.com
- Package perf-tips as docs.
- Include support for xz compressed images
* Mon Jan 11 2016 tonyj@suse.com
- Support strace/data.
* Sun Oct 11 2015 dmueller@suse.com
- enable numa support for aarch64
* Thu Jul 16 2015 antoine.belvire@laposte.net
- Remove perf-fix-branch-stack-mode-cannot-be-set.patch (upstreamed).
* Sun Jun 28 2015 antoine.belvire@laposte.net
- Fix build with GCC 5
  * perf-fix-branch-stack-mode-cannot-be-set.patch
* Wed May 13 2015 tonyj@suse.com
- Fix ppc64/ppc64le breakage due to libexecdir/libdir
* Mon Mar  9 2015 dimstar@opensuse.org
- Inject libdir=%%{_libdir} into make calls.
* Thu Jan  8 2015 dimstar@opensuse.org
- Remove build hack for kernel not building against glibc 2.20.
* Thu Nov 27 2014 dimstar@opensuse.org
- Build hack: if util/util.h does not (yet) define _DEFAULT_SOURCE,
  we export WERROR=0, which removes -Werror from CFLAGS. Once a
  kernel lands that defines _DEFAULT_SOURCE, we fail the build in
  to remove this hack, making it a (hopefully_ short-livinging one.
* Fri Jun 27 2014 tonyj@suse.com
- Build for s390[x] without libunwind (bnc#882855)
* Tue Mar 25 2014 aj@ajaissle.de
- Fix current build including 'trace event' plugins
- Do not include 'trace event' plugins when on armv7l
- BuildRequire libnuma-devel to enable 'perf bench numa mem', but
  only require if we build for ia64 x86_64 ppc64 ppc64le  ppc %%sparc
- Spec cleanup:
  * Add Url: https://perf.wiki.kernel.org/
  * Drop %%clean-section: We don't need to cleanup the buildroot
  * bash_completion.d/perf doesn't need executable bit
* Fri Jan 24 2014 tonyj@suse.com
- Fix build errors (invoke Makefile.perf directly to pass perfexecdir)
- Add /usr/bin/trace alias for perf (mainline b52bc234)
- Add libperf-gtk.so (loaded via dlsym, mainline fc67297b)
* Wed Dec  4 2013 tonyj@suse.com
- Drop patch perl-5.18-nowarn.patch (mainline)
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Wed Aug 21 2013 tonyj@suse.com
- Resolve build errors
- Drop patch perf-tests-ppc64-fix-compile-errors.patch (mainline)
- Refresh patch perl-5.18-nowarn.patch
* Wed Jul 10 2013 tonyj@suse.com
- Add patch 'perf-tests-ppc64-fix-compile-errors.patch' to resolve
  openSUSE:Factory:PowerPC testsuite build errors
* Tue Jul  9 2013 tonyj@suse.com
- Add audit-devel, gtk2-devel and libunwind-devel to support optional
  functionality.
- Add 'perl-5.18-nowarn.patch' to squelch build errors from perl.h
- Add perl_requires
- Fix --version output (copy submakefiles from kernel-source)
- Pass SUSE rpm optflags into make as EXTRA_CFLAGS not CFLAGS
- Stop building with V=1, make output easier to parse
* Tue Dec 25 2012 tonyj@suse.com
- Add /etc/bash_completion.d/perf to %%files (fix build error)
* Wed May 16 2012 toganm@opensuse.org
- Fix build for factory
  * added flex and bison to buildrequires
* Thu May  5 2011 idoenmez@novell.com
- Also copy arch/lib to fix compilation on x86-64
- Correctly depend on libdw-devel to fix dwarf support
- Add newt-devel dependency to enable text user interface
- Re-enable as-needed support since it works now
* Tue Mar  9 2010 tonyj@novell.com
- 2.6.33 changes
  add perf-bench, perf-buildid-list, perf-diff, perf-kmem, perf-probe and
  perf-trace-perl
  [Still pending, update of libdwarf to version > 20081231]
* Thu Nov  5 2009 tonyj@novell.com
- 2.6.32 changes
  add perf-sched, perf-timechart and perf-trace man pages
* Wed Aug 26 2009 aj@suse.de
- Remove libbfd.patch since it does not apply and use
  SUSE_ASNEEDED=0 instead.
- Set flag for asciidoc version 8.
* Sun Aug  2 2009 tonyj@suse.de
- Initial checkin of Performance Counters for Linux (PCL) userspace.
  This builds tools/perf out of kernel-source package and requires
  kernel >= 2.6.31
